﻿using DwC_A.Meta;
using System.Collections.Generic;

namespace DwC_A.Builders
{
    /// <summary>
    /// This class is generated by the FileBuilder class and passed into the BuildRows method.
    /// </summary>
    public class RowBuilder
    {
        private readonly IFileMetaData fileMetaData;
        private IList<string> fields = new List<string>();

        internal RowBuilder(IFileMetaData fileMetaData)
        {
            this.fileMetaData = fileMetaData;
        }

        /// <summary>
        /// Use this method to add a data field to a row in a file.
        /// </summary>
        /// <param name="field">Object containing the data to write to the field.  Uses the ToString() method of the object to write to the file.</param>
        /// <returns>this</returns>
        public RowBuilder AddField(object field)
        {
            fields.Add(fileMetaData.FieldsEnclosedBy + field.ToString() + fileMetaData.FieldsEnclosedBy);
            return this;
        }

        /// <summary>
        /// Call this method to generate a string that represents one row in the file.
        /// </summary>
        public string Build()
        {
            try
            {
                return string.Join(fileMetaData.FieldsTerminatedBy, fields);
            }
            finally
            {
                fields.Clear();
            }
        }
    }
}
